# Generated by Django 2.0.7 on 2018-07-26 17:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('phenotype_ontologies', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ontology',
            name='type',
            field=models.PositiveSmallIntegerField(choices=[(1, 'HP'), (2, 'MONDO'), (3, 'ONCOTREE')]),
        ),
    ]
